@@ -3,8 +3,9 @@ Main interface for ssm service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.ssm import (
+    from mypy_boto3_ssm import (
         Client,
         DescribeActivationsPaginator,
         DescribeAssociationExecutionTargetsPaginator,
@@ -47,7 +48,7 @@ Usage::
         ListResourceComplianceSummariesPaginator,
         ListResourceDataSyncPaginator,
         SSMClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -94,6 +95,7 @@ Usage::
     list_documents_paginator: ListDocumentsPaginator = client.get_paginator("list_documents")
     list_resource_compliance_summaries_paginator: ListResourceComplianceSummariesPaginator = client.get_paginator("list_resource_compliance_summaries")
     list_resource_data_sync_paginator: ListResourceDataSyncPaginator = client.get_paginator("list_resource_data_sync")
+    ```
 """
 from mypy_boto3_ssm.client import SSMClient as Client, SSMClient
 from mypy_boto3_ssm.paginator import (
