@@ -3,13 +3,15 @@ Main interface for ssm service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.ssm import SSMClient
+    from mypy_boto3_ssm import SSMClient
 
     session = boto3.Session()
 
     client: SSMClient = boto3.client("ssm")
     session_client: SSMClient = session.client("ssm")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
