@@ -3,8 +3,11 @@ Main interface for ssm service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.ssm import (
+
+    from mypy_boto3_ssm import SSMClient
+    from mypy_boto3_ssm import (
         DescribeActivationsPaginator,
         DescribeAssociationExecutionTargetsPaginator,
         DescribeAssociationExecutionsPaginator,
@@ -89,6 +92,7 @@ Usage::
     list_documents_paginator: ListDocumentsPaginator = client.get_paginator("list_documents")
     list_resource_compliance_summaries_paginator: ListResourceComplianceSummariesPaginator = client.get_paginator("list_resource_compliance_summaries")
     list_resource_data_sync_paginator: ListResourceDataSyncPaginator = client.get_paginator("list_resource_data_sync")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
